# Slot: default_curi_maps


ordered list of prefixcommon biocontexts to be fetched to resolve id_prefixes and inline prefix variables

URI: [http://w3id.org/biolink/biolinkml/meta/default_curi_maps](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [[String](String.md)]
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
